pub struct Instant(/* private fields */);Expand description
Implementations
Sourceimpl Instant
impl Instant
Sourcepub fn saturating_duration_since(self, earlier: Instant) -> Duration
pub fn saturating_duration_since(self, earlier: Instant) -> Duration
Returns the duration elapsed from earlier to self, saturating at zero
if earlier is later (clocks are monotonic, so this should not happen,
but saturation keeps the type panic-free, NFR-R1).
Sourcepub fn saturating_add(self, delta: Duration) -> Instant
pub fn saturating_add(self, delta: Duration) -> Instant
Returns the instant delta after self, saturating at the maximum.